==> cecil_0.4.3.orig.tar.gz: cecil-0.4.3/Mono.Cecil/PInvokeInfo.cs <==
//
// PInvokeInfo.cs
//
// Author:
//   Jb Evain (jbevain@gmail.com)
//
// (C) 2005 Jb Evain
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

namespace Mono.Cecil {

	public sealed class PInvokeInfo : IPInvokeInfo {

		MethodDefinition m_meth;

		PInvokeAttributes m_attributes;
		string m_entryPoint;
		ModuleReference m_module;

		public MethodDefinition Method {
			get { return m_meth; }
		}

		public PInvokeAttributes Attributes {
			get { return m_attributes; }
			set { m_attributes = value; }
		}

		public string EntryPoint {
			get { return m_entryPoint; }
			set { m_entryPoint = value; }
		}

		public ModuleReference Module {
			get { return m_module; }
			set { m_module = value; }
		}

		public PInvokeInfo (MethodDefinition meth)
		{
			m_meth = meth;
		}

		public PInvokeInfo (MethodDefinition meth, PInvokeAttributes attrs,
			string entryPoint, ModuleReference mod) : this (meth)
		{
			m_attributes = attrs;
			m_entryPoint = entryPoint;
			m_module = mod;
		}

		public void Accept (IReflectionVisitor visitor)
		{
			visitor.VisitPInvokeInfo (this);
		}
	}
}

==> cecil_0.5.orig.tar.gz: cecil-0.5/Mono.Cecil/PInvokeInfo.cs <==
//
// PInvokeInfo.cs
//
// Author:
//   Jb Evain (jbevain@gmail.com)
//
// (C) 2005 Jb Evain
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

namespace Mono.Cecil {

	public sealed class PInvokeInfo : IReflectionVisitable {

		MethodDefinition m_meth;

		PInvokeAttributes m_attributes;
		string m_entryPoint;
		ModuleReference m_module;

		public MethodDefinition Method {
			get { return m_meth; }
		}

		public PInvokeAttributes Attributes {
			get { return m_attributes; }
			set { m_attributes = value; }
		}

		public string EntryPoint {
			get { return m_entryPoint; }
			set { m_entryPoint = value; }
		}

		public ModuleReference Module {
			get { return m_module; }
			set { m_module = value; }
		}

		public PInvokeInfo (MethodDefinition meth)
		{
			m_meth = meth;
		}

		public PInvokeInfo (MethodDefinition meth, PInvokeAttributes attrs,
			string entryPoint, ModuleReference mod) : this (meth)
		{
			m_attributes = attrs;
			m_entryPoint = entryPoint;
			m_module = mod;
		}

		public void Accept (IReflectionVisitor visitor)
		{
			visitor.VisitPInvokeInfo (this);
		}
	}
}
